# AXTextAttributedString.h Documentation

## Overview
This header defines the keys used in dictionaries that describe attributed strings in the accessibility API.

## Constants

| Constant Name | Description |
| :--- | :--- |
| `kAXAttachmentTextAttribute` | Accessibility object representing a text attachment. |
| `kAXAutocorrectedTextAttribute` | Indicates whether the text was autocorrected. |
| `kAXBackgroundColorTextAttribute` | Describes the background color (CGColorRef). |
| `kAXFontFamilyKey` | Key for the font family name. |
| `kAXFontNameKey` | Key for the font name. |
| `kAXFontSizeKey` | Key for the font size. |
| `kAXFontTextAttribute` | Dictionary of font keys. |
| `kAXForegroundColorTextAttribute` | Describes the foreground color (CGColorRef). |
| `kAXLinkTextAttribute` | Access the object to which the specified range of text links. |
| `kAXMarkedMisspelledTextAttribute` | Indicates whether the text is visibly shown as misspelled. |
| `kAXMisspelledTextAttribute` | Indicates whether the text is misspelled. |
| `kAXNaturalLanguageTextAttribute` | Indicates the language in which the text will be spoken. |
| `kAXReplacementStringTextAttribute` | The string that will replace the text. |
| `kAXShadowTextAttribute` | Indicates whether the text displays shadow. |
| `kAXStrikethroughColorTextAttribute` | Color of the strikethrough (CGColorRef). |
| `kAXStrikethroughTextAttribute` | Indicates whether the text displays strikethrough. |
| `kAXSuperscriptTextAttribute` | Indicates whether the text is superscript or subscript. |
| `kAXUnderlineColorTextAttribute` | Color of the underlining (CGColorRef). |
| `kAXUnderlineTextAttribute` | Describes the underline style. |
| `kAXVisibleNameKey` | Key for the font display name. |
